* CIT_Industry_level.do
* Author: Giorgio_Thiago_Jawhar
* Date: [24_01_24]
* Purpose: Industry level analysis.



* Setting working directory
cd "${figures}/industry"

* Loading the balanced sample dataset
use "${final}/dw2022_CIT_clean.dta", clear
//
// * Decide the level of aggregation
 local levsecagg ind2dig 
//
// * Choose the variable for weighting and the year for weighting
local varforweight employees
local yearweight 2009
//
* Calculate weights
// bys cit_offshore `levsecagg': egen _t1 = sum(`varforweight') if year == `yearweight'
// bys cit_offshore `levsecagg': egen t1 = mean(_t1)  
// bys cit_offshore: egen _t2 = sum(`varforweight') if year == `yearweight'
// bys cit_offshore: egen t2 = mean(_t2)  
// gen weightvar = t1 / t2

* Calculate industry-level metrics
// collapse (mean) weightvar (sum) nfirms employees wagebill exportvalue revenue_beforetax revenue_export profits entry_d exit_d, ///
// 			by(year `levsecagg' cit_offshore sector_group_num)
collapse  (sum) nfirms employees wagebill exportvalue importvalue revenue_beforetax revenue_export profits entry_d exit_d, ///
			by(year `levsecagg' cit_offshore sector_group_num)

preserve 
	clear all
	use "${raw}/EU_TUN_WLD.dta"
	gen nat_2dig = substr(nat,1,2) 
	destring nat_2dig, generate(ind2dig) force
	collapse (sum) EU_WLD, by(year ind2dig)
	sort ind2dig year
	save "EU_W_2dig.dta", replace
restore

merge m:1 ind2dig year using "EU_W_2dig.dta"
drop if _merge == 2
drop _merge


*****NEW WEIGHTS (GARRET SUAREZ-SERRATO OHRN PAPER)
foreach var of varlist nfirms employees wagebill exportvalue importvalue revenue_beforetax revenue_export profits entry_d exit_d {
	egen _t1 = sum(`var') if year == 2009
	gen aux_weight_`var' = `var' / _t1 if year == 2009
	bys ind2dig cit_offshore: egen weight_`var' = mean(aux_weight_`var')
	
	
	gen aux_ref2013_`var' = `var' if year == 2009
	bys ind2dig cit_offshore: egen ref2013_`var' = mean(aux_ref2013_`var')
	gen delta_`var' = (`var'/ref2013_`var' - 1)
	winsor2 delta_`var', cut(0 99)
	
	drop _t1 aux_weight_`var' aux_ref2013_`var' ref2013_`var'
	
}


* Create an industry and offshore group variable
egen ind_offshore = group(`levsecagg' cit_offshore)

* Drop the base year
*drop if year == `yearweight'

* Define treatment variables
gen dummy2014 = (year >= 2014)
gen offshore_d2014 = cit_offshore * dummy2014

* Prepare for event study
gen treat = offshore_d2014
gen fid = ind_offshore 
gen become_treated = year if treat == 1
bys fid (year): egen first_treat = min(become_treated)
drop become_treated
gen ry = (year - first_treat)
tab ry

* Log-transform and create industry-level variables
foreach var in nfirms employees profits wagebill exportvalue importvalue revenue_export revenue_beforetax entry_d exit_d {
    gen ln_`var' = ln(`var' + (`var'^2 + 1)^.5)
}
gen ln_labprod = ln(revenue_beforetax / employees) if revenue_beforetax != . & revenue_beforetax > 0
gen ln_EU_W = ln(EU_WLD)
gen ln_EU_int = ln_EU_W * cit_offshore

gsort cit_offshore ind2dig year 
gen size_ref_aux = nfirms if year == 2013
bys cit_offshore ind2dig: egen size_ref = mean(size_ref_aux)
gen entry_rate = entry_d/size_ref
gen exit_rate = exit_d/size_ref

gen avg_wage = wagebill/employees if employees != .
gen ln_avg_wage =ln(avg_wage)

***SAVE INDUSTRY AGGREGATES
save "${output}/industry_dataset.dta", replace  
**********************************************************************************************************
******************************      REGRESSION FIGURES AND TABLES       **********************************
**********************************************************************************************************

global reg_vars "nfirms  entry_d exit_d employees wagebill revenue_beforetax importvalue"

***TWO WAY FE

**** FIGURES
foreach var in $reg_vars {
	cap est drop *
	qui eststo: reghdfe ln_`var' ib2013.year##cit_offshore , a(ind2dig##i.year) cluster(ind2dig)
	qui eststo: reghdfe ln_`var' ib2013.year##cit_offshore if sector_group_num == 2, a(ind2dig##i.year) cluster(ind2dig)

	coefplot *, keep(*year*1.cit*) vertical yline(0) omitted base ///
		coeflabel(2009.year*1.cit_offshore = "2009" 2010.year*1.cit_offshore = "2010"  2011.year*1.cit_offshore = "2011" ///
		2012.year*1.cit_offshore = "2012" 2013.year*1.cit_offshore = "2013"  2014.year*1.cit_offshore = "2014" ///
		2015.year*1.cit_offshore = "2015" 2016.year*1.cit_offshore = "2016"  2017.year*1.cit_offshore = "2017" ///
		2018.year*1.cit_offshore = "2018" 2019.year*1.cit_offshore = "2019") ytitle("Coefficient") ///
		graphregion(color(white)) legend(lab(2 "Full") lab(4 "Manufacturing"))
	 graph export "${figures}/industry/did_ind_`var'.png", replace
}

**** TABLE
cap est drop *
foreach var in $reg_vars {
	qui eststo: reghdfe ln_`var' dummy2014##cit_offshore, a(ind2dig##i.year) cluster(ind2dig)
	qui estadd scalar n_sectors = e(N_clust)
}

esttab using "${tables}/industry/did_ind_prepost.tex" , booktabs replace  f se(2) b(3) ///
	keep(1.dummy2014#1.cit_offshore) coeflabel(1.dummy2014#1.cit_offshore "Offshore $\times Post") ///
	stats(N n_sectors r2, labels(Observations "N sectors" "R-squared") fmt(%12.0fc %12.0fc %12.2fc)) ///
	refcat(1.dummy2014#1.cit_offshore "\emph{Full Sample}", nolabel)

	esttab ,    f se(2) b(3) ///
	keep(1.dummy2014#1.cit_offshore) coeflabel(1.dummy2014#1.cit_offshore "Offshore $\times Post") ///
	stats(N n_sectors r2, labels(Observations "N sectors" "R-squared") fmt(%12.0fc %12.0fc %12.2fc)) ///
	refcat(1.dummy2014#1.cit_offshore "\emph{Full Sample}")
	
cap est drop *	
foreach var in $reg_vars {
	qui eststo: reghdfe ln_`var' dummy2014##cit_offshore if sector_group_num == 2, a(ind2dig##i.year) cluster(ind2dig)
	qui estadd scalar n_sectors = e(N_clust)
}
esttab using "${tables}/industry/did_ind_prepost.tex" , booktabs append  f se(2) b(3) ///
	keep(1.dummy2014#1.cit_offshore) coeflabel(1.dummy2014#1.cit_offshore "Offshore $\times Post") nomtitle ///
	stats(N n_sectors r2, labels(Observations "N sectors" "R-squared") fmt(%12.0fc %12.0fc %12.2fc)) ///
	refcat(1.dummy2014#1.cit_offshore "\emph{Manufacturing Sample}", nolabel)
	
esttab ,    f se(2) b(3) ///
	keep(1.dummy2014#1.cit_offshore) coeflabel(1.dummy2014#1.cit_offshore "Offshore $\times Post")	
	


******************************NEW WEIGHTING (LN + WEIGHT BY VARIABLE)*********************************************	

global reg_vars_w "nfirms  entry_d exit_d employees wagebill revenue_beforetax "

replace weight_entry_d = weight_nfirms
replace weight_exit_d = weight_nfirms

**** FIGURES
foreach var in $reg_vars_w {
	cap est drop *
	qui eststo: reghdfe ln_`var' ib2013.year##cit_offshore if year != 2009							[aw = weight_`var'], a(ind2dig##i.year) cluster(ind2dig)
	qui eststo: reghdfe ln_`var' ib2013.year##cit_offshore if sector_group_num == 2 & year != 2009  [aw = weight_`var'], a(ind2dig##i.year) cluster(ind2dig)

	coefplot *, keep(*year*1.cit*) vertical yline(0) omitted base ///
		coeflabel(2009.year*1.cit_offshore = "2009" 2010.year*1.cit_offshore = "2010"  2011.year*1.cit_offshore = "2011" ///
		2012.year*1.cit_offshore = "2012" 2013.year*1.cit_offshore = "2013"  2014.year*1.cit_offshore = "2014" ///
		2015.year*1.cit_offshore = "2015" 2016.year*1.cit_offshore = "2016"  2017.year*1.cit_offshore = "2017" ///)
		2018.year*1.cit_offshore = "2018" 2019.year*1.cit_offshore = "2019") ytitle("Coefficient") ///
		graphregion(color(white)) legend(lab(2 "Full") lab(4 "Manufacturing"))
	 graph export "${figures}/industry/did_ind_lnw_`var'.png", replace
}

**** TABLE
global reg_vars_w_table "nfirms  entry_d exit_d employees wagebill revenue_beforetax  "
cap est drop *
foreach var in $reg_vars_w_table{
	qui eststo: reghdfe ln_`var' dummy2014##cit_offshore if year != 2009 [pw = weight_`var'], a(ind2dig##i.year) cluster(ind2dig)
	qui estadd scalar n_sectors = e(N_clust)
}

esttab using "${tables}/industry/did_ind_lnw_prepost.tex" , booktabs replace  f se(2) b(3) ///
	keep(1.dummy2014#1.cit_offshore) coeflabel(1.dummy2014#1.cit_offshore "Offshore $\times Post") ///
	stats(N n_sectors r2, labels(Observations "N sectors" "R-squared") fmt(%12.0fc %12.0fc %12.2fc)) ///
	refcat(1.dummy2014#1.cit_offshore "\emph{Full Sample}", nolabel) ///
	mtitles("Ln(N firms)" "Ln(N entries)" "Ln(N exits)" "Ln(N employess)" "Ln(Wagebill)" "Ln(Revenue)")

	esttab ,    f se(2) b(3) ///
	keep(1.dummy2014#1.cit_offshore) coeflabel(1.dummy2014#1.cit_offshore "Offshore $\times Post") ///
	stats(N n_sectors r2, labels(Observations "N sectors" "R-squared") fmt(%12.0fc %12.0fc %12.2fc)) ///
	refcat(1.dummy2014#1.cit_offshore "\emph{Full Sample}")
	
cap est drop *	
foreach var in $reg_vars_w_table {
	qui eststo: reghdfe ln_`var' dummy2014##cit_offshore if sector_group_num == 2 & year != 2009 [pw = weight_`var'], a(ind2dig##i.year) cluster(ind2dig)
	qui estadd scalar n_sectors = e(N_clust)
}
esttab using "${tables}/industry/did_ind_lnw_prepost.tex" , booktabs append  f se(2) b(3) ///
	keep(1.dummy2014#1.cit_offshore) coeflabel(1.dummy2014#1.cit_offshore "Offshore $\times Post") nomtitle nonum ///
	stats(N n_sectors r2, labels(Observations "N sectors" "R-squared") fmt(%12.0fc %12.0fc %12.2fc)) ///
	refcat(1.dummy2014#1.cit_offshore "\emph{Manufacturing Sample}", nolabel)
	
esttab ,    f se(2) b(3) ///
	keep(1.dummy2014#1.cit_offshore) coeflabel(1.dummy2014#1.cit_offshore "Offshore $\times Post")
	
	
******************************NEW WEIGHTING (GSSO)*********************************************	
foreach var of varlist nfirms employees wagebill exportvalue revenue_beforetax revenue_export profits entry_d exit_d {
	drop  delta_`var'_w
	winsor2 delta_`var', cut(0 95)
}

**** FIGURES
foreach var in $reg_vars_w {
	cap est drop *
	qui eststo: reghdfe delta_`var'_w ib2013.year##cit_offshore if year != 2009 						 [pw = weight_`var'], a(ind2dig##i.year) cluster(ind2dig)
	qui eststo: reghdfe delta_`var'_w ib2013.year##cit_offshore if year != 2009 & sector_group_num == 2  [pw = weight_`var'], a(ind2dig##i.year) cluster(ind2dig)

	coefplot *, keep(*year*1.cit*) vertical yline(0) omitted base ///
		coeflabel(2009.year*1.cit_offshore = "2009" 2010.year*1.cit_offshore = "2010"  2011.year*1.cit_offshore = "2011" ///
		2012.year*1.cit_offshore = "2012" 2013.year*1.cit_offshore = "2013"  2014.year*1.cit_offshore = "2014" ///
		2015.year*1.cit_offshore = "2015" 2016.year*1.cit_offshore = "2016"  2017.year*1.cit_offshore = "2017" ///)
		2018.year*1.cit_offshore = "2018" 2019.year*1.cit_offshore = "2019") ytitle("Coefficient") ///
		graphregion(color(white)) legend(lab(2 "Full") lab(4 "Manufacturing"))
	 graph export "${figures}/industry/did_ind_w_`var'.png", replace
}

**********************************************************************************
**********************************************************************************

***TWO WAY FE WITH EU-IMPORT - OFFSHORE INTERACTION
global reg_vars "avg_wage nfirms  entry_d exit_d employees wagebill revenue_beforetax profits revenue_export exportvalue  labprod"

**** FIGURES
foreach var in $reg_vars {
	cap est drop *
	qui eststo: reghdfe ln_`var' ib2013.year##cit_offshore ln_EU_int, a(ind2dig##i.year) cluster(ind2dig)
	qui eststo: reghdfe ln_`var' ib2013.year##cit_offshore ln_EU_int if sector_group_num == 2, a(ind2dig##i.year) cluster(ind2dig)

	coefplot *, keep(*year*1.cit*) vertical yline(0) omitted base ///
		coeflabel(2009.year*1.cit_offshore = "2009" 2010.year*1.cit_offshore = "2010"  2011.year*1.cit_offshore = "2011" ///
		2012.year*1.cit_offshore = "2012" 2013.year*1.cit_offshore = "2013"  2014.year*1.cit_offshore = "2014" ///
		2015.year*1.cit_offshore = "2015" 2016.year*1.cit_offshore = "2016"  2017.year*1.cit_offshore = "2017" ///)
		2018.year*1.cit_offshore = "2018" 2019.year*1.cit_offshore = "2019") ytitle("Coefficient") ///
		graphregion(color(white)) legend(lab(2 "Full") lab(4 "Manufacturing"))
	 graph export "${figures}/industry/did_ind_EUimp_`var'.png", replace
	 
}	
******************************NEW WEIGHTING (LN + WEIGHT BY VARIABLE)*********************************************	
******************************ADDITIONAL CONTROLS *********************************************	
 
merge m:1 year using "${raw}/Naccounts_tunis.dta"

rename cons consumption

gen xrate_offshore = (xrate)*cit_offshore
gen cons_offshore = (consumption/gdp)*cit_offshore

**** TABLE
global reg_vars_w_table "nfirms  entry_d exit_d employees wagebill revenue_beforetax"
cap est drop *
foreach var in $reg_vars_w_table{
	 eststo: reghdfe ln_`var' dummy2014##cit_offshore cons_offshore xrate_offshore if year != 2009 [pw = weight_`var'], a(ind2dig##i.year) cluster(ind2dig)
	 estadd scalar n_sectors = e(N_clust)
}

esttab using "${tables}/did_ind_lnw_prepost_contr.tex" , booktabs replace  f se(2) b(3) ///
	keep(1.dummy2014#1.cit_offshore cons_offshore xrate_offshore) coeflabel(1.dummy2014#1.cit_offshore "Offshore $\times Post" cons_offshore "Offshore $\times Consumption/GDP" xrate_offshore "Offshore $\times Xrate") ///
	stats(N n_sectors r2, labels(Observations "N sectors" "R-squared") fmt(%12.0fc %12.0fc %12.2fc)) ///
	refcat(1.dummy2014#1.cit_offshore "\emph{Full Sample}", nolabel) ///
	mtitles("Ln(N firms)" "Ln(N entries)" "Ln(N exits)" "Ln(N employess)" "Ln(Wagebill)" "Ln(Revenue)")

	esttab ,    f se(2) b(3) ///
	keep(1.dummy2014#1.cit_offshore xrate_offshore   cons_offshore  ) coeflabel(1.dummy2014#1.cit_offshore "Offshore $\times Post" cons_offshore "Offshore $\times Consumption/GDP" xrate_offshore "Offshore $\times Xrate") ///
	stats(N n_sectors r2, labels(Observations "N sectors" "R-squared") fmt(%12.0fc %12.0fc %12.2fc)) ///
	refcat(1.dummy2014#1.cit_offshore "\emph{Full Sample}")
	
cap est drop *	
foreach var in $reg_vars_w_table {
	qui eststo: reghdfe ln_`var' dummy2014##cit_offshore cons_offshore xrate_offshore if sector_group_num == 2 & year != 2009 [pw = weight_`var'], a(ind2dig##i.year) cluster(ind2dig)
	qui estadd scalar n_sectors = e(N_clust)
}
esttab using "${tables}/did_ind_lnw_prepost_contr.tex" , booktabs append  f se(2) b(3) ///
	keep(1.dummy2014#1.cit_offshore cons_offshore xrate_offshore) coeflabel(1.dummy2014#1.cit_offshore "Offshore $\times Post" cons_offshore "Offshore $\times Consumption/GDP" xrate_offshore "Offshore $\times Xrate") nomtitle nonum ///
	stats(N n_sectors r2, labels(Observations "N sectors" "R-squared") fmt(%12.0fc %12.0fc %12.2fc)) ///
	refcat(1.dummy2014#1.cit_offshore "\emph{Manufacturing Sample}", nolabel)
	
esttab ,    f se(2) b(3) ///
	keep(1.dummy2014#1.cit_offshore cons_offshore xrate_offshore) coeflabel(1.dummy2014#1.cit_offshore "Offshore $\times Post" cons_offshore "Offshore $\times Consumption/GDP" xrate_offshore "Offshore $\times Xrate")

	
***TWO WAY FE ONLY DOMESTIC FIRMS
* This part does not run without the full data 
/*
use "${final}/industry_dataset_foreign.dta",clear

keep if foreign==0 & year>=2009

global reg_vars "nfirms  entry_d exit_d employees wagebill revenue_beforetax"

**** FIGURES
foreach var in $reg_vars {
	cap est drop *
	qui eststo: reghdfe ln_`var' ib2013.year##cit_offshore c.year##cit_offshore if year != 2009 [pw = weight_`var'], a(ind2dig##i.year) cluster(ind2dig)
	qui eststo: reghdfe ln_`var' ib2013.year##cit_offshore c.year##cit_offshore if year != 2009  & sector_group_num == 2 [pw = weight_`var'], a(ind2dig##i.year) cluster(ind2dig)

	coefplot *, keep(*year*1.cit*) vertical yline(0) omitted base ///
		coeflabel(2009.year*1.cit_offshore = "2009" 2010.year*1.cit_offshore = "2010"  2011.year*1.cit_offshore = "2011" ///
		2012.year*1.cit_offshore = "2012" 2013.year*1.cit_offshore = "2013"  2014.year*1.cit_offshore = "2014" ///
		2015.year*1.cit_offshore = "2015" 2016.year*1.cit_offshore = "2016"  2017.year*1.cit_offshore = "2017" ///)
		2018.year*1.cit_offshore = "2018" 2019.year*1.cit_offshore = "2019") ytitle("Coefficient") ///
		graphregion(color(white)) legend(lab(2 "Full") lab(4 "Manufacturing"))
		
	 graph export "${figures}/industry/did_ind_dom_`var'.png", replace
}
*/